<?php

namespace Drupal\Tests\votingapi_reaction\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the creation of reaction field.
 *
 * @group VotingAPIReaction
 */
class ReactionFieldTest extends BrowserTestBase {

  /**
   * The node object.
   *
   * @var \Drupal\node\NodeInterface
   */
  protected $node;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node', 'file', 'field_ui', 'votingapi', 'votingapi_reaction',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    if ($this->profile != 'standard') {
      $this->drupalCreateContentType([
        'type' => 'article',
        'name' => 'Article',
        'display_submitted' => FALSE,
      ]);
    }

    $this->drupalLogin($this->createUser([], null, TRUE));
  }

  /**
   * Tests creating a reaction field.
   */
  public function testReactionField(): void {
    $assert = $this->assertSession();
    $page = $this->getSession()->getPage();

    $this->drupalGet('/admin/structure/types/manage/article/fields/add-field');

    // Create the field.
    $assert->addressEquals('/admin/structure/types/manage/article/fields/add-field');
    $page->selectFieldOption('new_storage_type', 'votingapi_reaction');
    $page->fillField('label', 'Reaction');
    $page->fillField('field_name', 'reaction');
    $page->pressButton('op');

    // Configure the storage settings.
    $assert->addressEquals('/admin/structure/types/manage/article/fields/node.article.field_reaction/storage');
    $page->pressButton('op');

    // Configure the field settings.
    $assert->addressEquals('/admin/structure/types/manage/article/fields/node.article.field_reaction');
    $page->pressButton('op');

    // Check if field was created.
    $assert->addressEquals('/admin/structure/types/manage/article/fields');
    $assert->pageTextContains("Saved Reaction configuration.");

    // Check if default values were saved.
    $this->drupalGet('/admin/structure/types/manage/article/fields/node.article.field_reaction');
    $assert->checkboxChecked('settings[anonymous_detection][1]');
    $assert->checkboxChecked('settings[anonymous_detection][2]');
    $assert->checkboxChecked('settings[reactions][reaction_angry]');
    $assert->checkboxChecked('settings[reactions][reaction_laughing]');
    $assert->checkboxChecked('settings[reactions][reaction_like]');
    $assert->checkboxChecked('settings[reactions][reaction_love]');
    $assert->checkboxChecked('settings[reactions][reaction_sad]');
    $assert->checkboxChecked('settings[reactions][reaction_surprised]');
    $assert->fieldValueEquals('settings[anonymous_rollover]', '-1');
    $assert->fieldValueEquals('default_value_input[field_reaction][0][status]', '2');
  }

}
